@@ -11,13 +11,13 @@ integer izamax_(integer *n, doublecomplex *zx, integer *incx)
 
 
     /* System generated locals */
-    integer ret_val, i__1;
+integer ret_val, i__1;
 
     /* Local variables */
-    static doublereal smax;
-    static integer i;
+    doublereal smax;
+    integer i;
     extern doublereal dcabs1_(doublecomplex *);
-    static integer ix;
+    integer ix;
 
 
 /*     finds the index of element having max. absolute value.   
@@ -49,7 +49,6 @@ integer izamax_(integer *n, doublecomplex *zx, integer *incx)
     ix = 1;
     smax = dcabs1_(&ZX(1));
     ix += *incx;
-    i__1 = *n;
     for (i = 2; i <= *n; ++i) {
 	if (dcabs1_(&ZX(ix)) <= smax) {
 	    goto L5;
@@ -66,7 +65,6 @@ L5:
 
 L20:
     smax = dcabs1_(&ZX(1));
-    i__1 = *n;
     for (i = 2; i <= *n; ++i) {
 	if (dcabs1_(&ZX(i)) <= smax) {
 	    goto L30;
