@@ -1,4 +1,4 @@
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -16,7 +16,13 @@ at the top-level directory.
  * October 15, 2003
  *
  */
-#include <unistd.h>
+
+/*! \file
+ * \brief LU factorization from dgstrf (DGSSV)
+ *
+ * \ingroup Example
+ */
+
 #include "slu_ddefs.h"
 
 int main(int argc, char *argv[])
@@ -93,6 +99,7 @@ int main(int argc, char *argv[])
 
 	/* This is how you could access the solution matrix. */
         double *sol = (double*) ((DNformat*) B.Store)->nzval; 
+        (void)sol;  // suppress unused variable warning
 
 	 /* Compute the infinity norm of the error. */
 	dinf_norm_error(nrhs, &B, xact);
@@ -132,5 +139,6 @@ int main(int argc, char *argv[])
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Exit main()");
 #endif
+    return EXIT_SUCCESS;
 }
 
