@@ -1,4 +1,4 @@
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -16,7 +16,14 @@ at the top-level directory.
  * August 1, 2008
  *
  */
-#include <unistd.h>
+
+/*! \file
+ * \brief factorization from dgstrf (DGSSVX)
+ *
+ * \ingroup Example
+ */
+
+#include <getopt.h>
 #include "slu_sdefs.h"
 
 int main(int argc, char *argv[])
@@ -39,7 +46,7 @@ int main(int argc, char *argv[])
     void           *work;
     int            nrhs, ldx;
     int_t          info, lwork, nnz;
-    int            i, m, n;
+    int            m, n;
     float         *rhsb, *rhsx, *xact;
     float         *R, *C;
     float         *ferr, *berr;
@@ -139,6 +146,7 @@ int main(int argc, char *argv[])
 
         /* This is how you could access the solution matrix. */
         float *sol = (float*) ((DNformat*) X.Store)->nzval; 
+        (void)sol;  // suppress unused variable warning
 
 	if ( options.PivotGrowth == YES )
             printf("Recip. pivot growth = %e\n", rpg);
@@ -147,7 +155,7 @@ int main(int argc, char *argv[])
 	if ( options.IterRefine != NOREFINE ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-	    for (i = 0; i < nrhs; ++i)
+            for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
         Lstore = (SCformat *) L.Store;
@@ -192,11 +200,12 @@ int main(int argc, char *argv[])
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Exit main()");
 #endif
+    return EXIT_SUCCESS;
 }
 
 
-/*  
- * Parse command line inputs.
+/*!
+ * \brief Parse command line inputs.
  */
 void
 parse_command_line(int argc, char *argv[], int *lwork,
