@@ -1,4 +1,4 @@
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -8,36 +8,35 @@ All rights reserved.
 The source code is distributed under BSD license, see the file License.txt
 at the top-level directory.
 */
-/*! @file superlu.c
- * \brief a small 5x5 example
- * 
- * <pre>
- * * -- SuperLU routine (version 2.0) --
+
+/* * -- SuperLU routine (version 2.0) --
  * Univ. of California Berkeley, Xerox Palo Alto Research Center,
  * and Lawrence Berkeley National Lab.
  * November 15, 1997
- * </pre>
  */
-#include "slu_ddefs.h"
 
-main(int argc, char *argv[])
-{
-/*
- * Purpose
- * =======
- * 
- * This is the small 5x5 example used in the Sections 2 and 3 of the 
+/*! \file
+ * \brief a small 5x5 example
+ *
+ * This is the small 5x5 example used in the Sections 2 and 3 of the
  * Users' Guide to illustrate how to call a SuperLU routine, and the
  * matrix data structures used by SuperLU.
  *
+ * \ingroup Example
  */
+
+#include "slu_ddefs.h"
+
+int main(int argc, char *argv[])
+{
     SuperMatrix A, L, U, B;
     double   *a, *rhs;
     double   s, u, p, e, r, l;
-    int      *asub, *xa;
+    int_t    *asub, *xa;
     int      *perm_r; /* row permutations from partial pivoting */
     int      *perm_c; /* column permutation vector */
-    int      nrhs, info, i, m, n, nnz, permc_spec;
+    int      nrhs, m, n;
+    int_t    info, nnz;
     superlu_options_t options;
     SuperLUStat_t stat;
 
@@ -61,11 +60,12 @@ main(int argc, char *argv[])
     /* Create right-hand side matrix B. */
     nrhs = 1;
     if ( !(rhs = doubleMalloc(m * nrhs)) ) ABORT("Malloc fails for rhs[].");
-    for (i = 0; i < m; ++i) rhs[i] = 1.0;
+    for (int i = 0; i < m; ++i)
+        rhs[i] = 1.0;
     dCreate_Dense_Matrix(&B, m, nrhs, rhs, m, SLU_DN, SLU_D, SLU_GE);
 
-    if ( !(perm_r = intMalloc(m)) ) ABORT("Malloc fails for perm_r[].");
-    if ( !(perm_c = intMalloc(n)) ) ABORT("Malloc fails for perm_c[].");
+    if ( !(perm_r = int32Malloc(m)) ) ABORT("Malloc fails for perm_r[].");
+    if ( !(perm_c = int32Malloc(n)) ) ABORT("Malloc fails for perm_c[].");
 
     /* Set the default input options. */
     set_default_options(&options);
@@ -91,4 +91,6 @@ main(int argc, char *argv[])
     Destroy_SuperNode_Matrix(&L);
     Destroy_CompCol_Matrix(&U);
     StatFree(&stat);
+
+    return EXIT_SUCCESS;
 }
