@@ -1,4 +1,4 @@
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -9,20 +9,20 @@ The source code is distributed under BSD license, see the file License.txt
 at the top-level directory.
 */
 
-/*! @file zitersol.c
- * \brief Example #1 showing how to use ILU to precondition GMRES
- *
- * <pre>
- * -- SuperLU routine (version 5.0) --
+/* -- SuperLU routine (version 5.0) --
  * Lawrence Berkeley National Laboratory
  * November, 2010
  * August, 2011
+ */
+
+/*! \file
+ * \brief Example #1 showing how to use ILU to precondition GMRES
  *
  * This example shows that ILU is computed from the equilibrated matrix,
  * and the preconditioned GMRES is applied to the equilibrated system.
  * The driver routine ZGSISX is called twice to perform factorization
  * and apply preconditioner separately.
- * 
+ *
  * Note that ZGSISX performs the following factorization:
  *     Pr*Dr*A*Dc*Pc^T ~= LU
  * with Pr being obtained from MC64 statically then partial pivoting
@@ -33,11 +33,10 @@ at the top-level directory.
  * Then GMRES step requires requires 2 procedures:
  *   1) Apply preconditioner M^{-1} = Pc^T*U^{-1}*L^{-1}*Pr
  *   2) Matrix-vector multiplication: w = A1*v
- * 
- * </pre>
+ *
+ * \ingroup Example
  */
 
-#include <unistd.h>
 #include "slu_zdefs.h"
 
 superlu_options_t *GLOBAL_OPTIONS;
@@ -47,10 +46,16 @@ SuperMatrix *GLOBAL_A, *GLOBAL_L, *GLOBAL_U;
 SuperLUStat_t *GLOBAL_STAT;
 mem_usage_t   *GLOBAL_MEM_USAGE;
 
-void zpsolve(int n,
-                  doublecomplex x[], /* solution */
-                  doublecomplex y[]  /* right-hand side */
-)
+/*!
+ * \brief Performs zgsisx with original matrix A.
+ *
+ * See documentation of zgsisx for more details.
+ *
+ * \param [in] n     Dimension of matrices
+ * \param [out] x    Solution
+ * \param [in,out] y Right-hand side
+ */
+void zpsolve(int n, doublecomplex x[], doublecomplex y[])
 {
     SuperMatrix *A = GLOBAL_A, *L = GLOBAL_L, *U = GLOBAL_U;
     SuperLUStat_t *stat = GLOBAL_STAT;
@@ -80,6 +85,18 @@ void zpsolve(int n,
 #endif
 }
 
+/*!
+ * \brief Performs matrix-vector multipliation sp_zgem with original matrix A.
+ *
+ * The operations is y := alpha*A*x + beta*y. See documentation of sp_zgem
+ * for further details.
+ *
+ * \param [in] alpha Scalar factor for A*x
+ * \param [in] x Vector to multiply with A
+ * \param [in] beta Scalar factor for y
+ * \param [in,out] y Vector to add to to matrix-vector multiplication and
+ *                   storage for result.
+ */
 void zmatvec_mult(doublecomplex alpha, doublecomplex x[], doublecomplex beta, doublecomplex y[])
 {
     SuperMatrix *A = GLOBAL_A;
@@ -99,7 +116,6 @@ int main(int argc, char *argv[])
     extern int zfill_diag(int n, NCformat *Astore);
 
     char     equed[1] = {'B'};
-    yes_no_t equil;
     trans_t  trans;
     SuperMatrix A, L, U;
     SuperMatrix B, X;
@@ -118,7 +134,7 @@ int main(int argc, char *argv[])
     doublecomplex   *rhsb, *rhsx, *xact;
     doublecomplex   *work = NULL;
     double   *R, *C;
-    double   u, rpg, rcond;
+    double   rpg, rcond;
     doublecomplex zero = {0.0, 0.0};
     doublecomplex one = {1.0, 0.0};
     doublecomplex none = {-1.0, 0.0};
@@ -127,8 +143,6 @@ int main(int argc, char *argv[])
     SuperLUStat_t stat;
     FILE 	  *fp = stdin;
 
-    int restrt, iter, maxit, i;
-    double resid;
     doublecomplex *x, *b;
 
 #ifdef DEBUG
@@ -182,7 +196,7 @@ int main(int argc, char *argv[])
 		"-r -rb:\n\t[INPUT] is a Rutherford-Boeing format matrix.\n"
 		"-t -triplet:\n\t[INPUT] is a triplet format matrix.\n",
 		argv[0]);
-	return 0;
+        return EXIT_FAILURE;
     }
     else
     {
@@ -205,7 +219,7 @@ int main(int argc, char *argv[])
 		break;
 	    default:
 		printf("Unrecognized format.\n");
-		return 0;
+                return EXIT_FAILURE;
 	}
     }
 
@@ -252,9 +266,11 @@ int main(int argc, char *argv[])
     /* Set RHS for GMRES. */
     if (!(b = doublecomplexMalloc(m))) ABORT("Malloc fails for b[].");
     if (*equed == 'R' || *equed == 'B') {
-	for (i = 0; i < n; ++i) zd_mult(&b[i], &rhsb[i], R[i]);
+        for (int i = 0; i < n; ++i)
+            zd_mult(&b[i], &rhsb[i], R[i]);
     } else {
-	for (i = 0; i < m; i++) b[i] = rhsb[i];
+        for (int i = 0; i < m; i++)
+            b[i] = rhsb[i];
     }
 
     printf("zgsisx(): info %lld, equed %c\n", (long long)info, equed[0]);
@@ -301,10 +317,10 @@ int main(int argc, char *argv[])
     options.ConditionNumber = NO;
 
     /* Set the variables used by GMRES. */
-    restrt = SUPERLU_MIN(n / 3 + 1, 50);
-    maxit = 1000;
-    iter = maxit;
-    resid = 1e-8;
+    int restrt = SUPERLU_MIN(n / 3 + 1, 50);
+    int maxit = 1000;
+    int iter = maxit;
+    double resid = 1e-8;
     if (!(x = doublecomplexMalloc(n))) ABORT("Malloc fails for x[].");
 
     if (info <= n + 1)
@@ -315,8 +331,9 @@ int main(int argc, char *argv[])
 	extern double dznrm2_(int *, doublecomplex [], int *);
 	extern void zaxpy_(int *, doublecomplex *, doublecomplex [], int *, doublecomplex [], int *);
 
-	/* Initial guess */
-	for (i = 0; i < n; i++) x[i] = zero;
+        /* Initial guess */
+        for (int i = 0; i < n; i++)
+            x[i] = zero;
 
 	t = SuperLU_timer_();
 
@@ -346,9 +363,10 @@ int main(int argc, char *argv[])
 
 	/* Scale the solution back if equilibration was performed. */
 	if (*equed == 'C' || *equed == 'B') 
-	    for (i = 0; i < n; i++) zd_mult(&x[i], &x[i], C[i]);
+            for (int i = 0; i < n; i++)
+                zd_mult(&x[i], &x[i], C[i]);
 
-	for (i = 0; i < m; i++) {
+        for (int i = 0; i < m; i++) {
             z_sub(&temp, &x[i], &xact[i]);
             maxferr = SUPERLU_MAX(maxferr, z_abs1(&temp));
         }
@@ -385,5 +403,5 @@ int main(int argc, char *argv[])
     CHECK_MALLOC("Exit main()");
 #endif
 
-    return 0;
+    return EXIT_SUCCESS;
 }
