@@ -1,4 +1,4 @@
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -18,24 +18,27 @@ at the top-level directory.
  * Last update: July 10, 2015
  *
  */
-#include <unistd.h>
+
+/*! \file
+ * \brief ZGSSVX to solve systems with the same matrix but different right-hand side.
+ *
+ * \ingroup Example
+ */
+
+#include <getopt.h>
 #include "slu_zdefs.h"
 
-int main(int argc, char *argv[])
-{
-/*
- * Purpose
- * =======
- *
- * The driver program ZLINSOLX1.
+/*!
+ * \brief The driver program ZLINSOLX1.
  *
  * This example illustrates how to use ZGSSVX to solve systems with the same
  * A but different right-hand side.
  * In this case, we factorize A only once in the first call to DGSSVX,
  * and reuse the following data structures in the subsequent call to ZGSSVX:
  *     perm_c, perm_r, R, C, L, U.
- * 
  */
+int main(int argc, char *argv[])
+{
     char           equed[1];
     yes_no_t       equil;
     trans_t        trans;
@@ -52,7 +55,7 @@ int main(int argc, char *argv[])
     int            *perm_r; /* row permutations from partial pivoting */
     int            *etree;
     void           *work;
-    int            i, m, n, nrhs, ldx;
+    int            m, n, nrhs, ldx;
     int_t          info, lwork, nnz;
     doublecomplex         *rhsb, *rhsx, *xact;
     double         *R, *C;
@@ -184,11 +187,12 @@ int main(int argc, char *argv[])
 
         /* This is how you could access the solution matrix. */
         doublecomplex *sol = (doublecomplex*) ((DNformat*) X.Store)->nzval; 
+        (void)sol;  // suppress unused variable warning
 
 	if ( options.IterRefine ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-	    for (i = 0; i < nrhs; ++i)
+            for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
@@ -223,10 +227,11 @@ int main(int argc, char *argv[])
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Exit main()");
 #endif
+    return EXIT_SUCCESS;
 }
 
-/*  
- * Parse command line options to get relaxed snode size, panel size, etc.
+/*!
+ * \brief Parse command line options to get relaxed snode size, panel size, etc.
  */
 void
 parse_command_line(int argc, char *argv[], int *lwork,
