@@ -1,4 +1,4 @@
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -18,24 +18,27 @@ at the top-level directory.
  * Last update: July 10, 2015
  *
  */
-#include <unistd.h>
+
+/*! \file
+ * \brief ZGSSVX to solve systems repeatedly with the same sparsity pattern of matrix A.
+ *
+ * \ingroup Example
+ */
+
+#include <getopt.h>
 #include "slu_zdefs.h"
 
-int main(int argc, char *argv[])
-{
-/*
- * Purpose
- * =======
- *
- * The driver program ZLINSOLX2.
+/*!
+ * \brief The driver program ZLINSOLX2.
  *
  * This example illustrates how to use ZGSSVX to solve systems repeatedly
  * with the same sparsity pattern of matrix A.
  * In this case, the column permutation vector perm_c is computed once.
  * The following data structures will be reused in the subsequent call to
  * ZGSSVX: perm_c, etree
- * 
  */
+int main(int argc, char *argv[])
+{
     char           equed[1];
     yes_no_t       equil;
     trans_t        trans;
@@ -53,7 +56,7 @@ int main(int argc, char *argv[])
     int            *etree;
     void           *work;
     int            m, n, nrhs, ldx;
-    int_t          i, j, info, lwork, nnz;
+    int_t          info, lwork, nnz;
     doublecomplex         *rhsb, *rhsb1, *rhsx, *xact;
     double         *R, *C;
     double         *ferr, *berr;
@@ -108,11 +111,12 @@ int main(int argc, char *argv[])
     if ( !(a1 = doublecomplexMalloc(nnz)) ) ABORT("Malloc fails for a1[].");
     if ( !(asub1 = intMalloc(nnz)) ) ABORT("Malloc fails for asub1[].");
     if ( !(xa1 = intMalloc(n+1)) ) ABORT("Malloc fails for xa1[].");
-    for (i = 0; i < nnz; ++i) {
+    for (int i = 0; i < nnz; ++i) {
         a1[i] = a[i];
 	asub1[i] = asub[i];
     }
-    for (i = 0; i < n+1; ++i) xa1[i] = xa[i];
+    for (int i = 0; i < n+1; ++i)
+        xa1[i] = xa[i];
     
     zCreate_CompCol_Matrix(&A, m, n, nnz, a, asub, xa, SLU_NC, SLU_Z, SLU_GE);
     Astore = A.Store;
@@ -127,8 +131,9 @@ int main(int argc, char *argv[])
     ldx = n;
     zGenXtrue(n, nrhs, xact, ldx);
     zFillRHS(trans, nrhs, xact, ldx, &A, &B);
-    for (j = 0; j < nrhs; ++j)
-        for (i = 0; i < m; ++i) rhsb1[i+j*m] = rhsb[i+j*m];
+    for (int j = 0; j < nrhs; ++j)
+        for (int i = 0; i < m; ++i)
+            rhsb1[i+j*m] = rhsb[i+j*m];
     
     if ( !(perm_c = int32Malloc(n)) ) ABORT("Malloc fails for perm_c[].");
     if ( !(perm_r = int32Malloc(m)) ) ABORT("Malloc fails for perm_r[].");
@@ -158,6 +163,7 @@ int main(int argc, char *argv[])
 
         /* This is how you could access the solution matrix. */
         doublecomplex *sol = (doublecomplex*) ((DNformat*) X.Store)->nzval; 
+        (void)sol;  // suppress unused variable warning
 
 	if ( options.PivotGrowth ) printf("Recip. pivot growth = %e\n", rpg);
 	if ( options.ConditionNumber )
@@ -174,7 +180,7 @@ int main(int argc, char *argv[])
 	if ( options.IterRefine ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-	    for (i = 0; i < nrhs; ++i)
+            for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", (int)i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
@@ -213,6 +219,7 @@ int main(int argc, char *argv[])
 
         /* This is how you could access the solution matrix. */
         doublecomplex *sol = (doublecomplex*) ((DNformat*) X.Store)->nzval; 
+        (void)sol;  // suppress unused variable warning
 
 	if ( options.PivotGrowth ) printf("Recip. pivot growth = %e\n", rpg);
 	if ( options.ConditionNumber )
@@ -227,7 +234,7 @@ int main(int argc, char *argv[])
 	if ( options.IterRefine ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-	    for (i = 0; i < nrhs; ++i)
+            for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", (int)i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
@@ -259,10 +266,11 @@ int main(int argc, char *argv[])
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Exit main()");
 #endif
+    return EXIT_SUCCESS;
 }
 
-/*  
- * Parse command line options to get relaxed snode size, panel size, etc.
+/*!
+ * \brief Parse command line options to get relaxed snode size, panel size, etc.
  */
 void
 parse_command_line(int argc, char *argv[], int *lwork,
