@@ -87,7 +87,7 @@ zgscon(char *norm, SuperMatrix *L, SuperMatrix *U,
 
 
     /* Local variables */
-    int    kase, kase1, onenrm, i;
+    int    kase, kase1, onenrm;
     double ainvnm;
     doublecomplex *work;
     int    isave[3];
