@@ -1,27 +1,28 @@
 /*  -- translated by f2c (version 19940927).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
 */
+#include <math.h>
+#include <stdbool.h>
+#include <stdlib.h>
 #include <string.h>
-#include "f2c.h"
+#include "../../SRC/slu_sdefs.h"
 
 /* Table of constant values */
 
 static complex c_b1 = {0.f,0.f};
 static complex c_b2 = {1.f,0.f};
-static integer c__1 = 1;
-static integer c__0 = 0;
-static integer c__5 = 5;
+static int c__1 = 1;
+static int c__0 = 0;
+static int c__5 = 5;
 
-/* Subroutine */ int clatme_slu(integer *n, char *dist, integer *iseed, complex *
-	d, integer *mode, real *cond, complex *dmax__, char *ei, char *rsign, 
-	char *upper, char *sim, real *ds, integer *modes, real *conds, 
-	integer *kl, integer *ku, real *anorm, complex *a, integer *lda, 
-	complex *work, integer *info)
+/* Subroutine */ int clatme_slu(int *n, char *dist, int *iseed, complex *
+	d, int *mode, float *cond, complex *dmax__, char *ei, char *rsign,
+	char *upper, char *sim, float *ds, int *modes, float *conds,
+	int *kl, int *ku, float *anorm, complex *a, int *lda,
+	complex *work, int *info)
 {
     /* System generated locals */
-    integer a_dim1, a_offset, i__1, i__2;
-    real r__1, r__2;
+    int a_dim1, a_offset, i__1, i__2;
+    float r__1, r__2;
     complex q__1, q__2;
 
     /* Builtin functions */
@@ -29,46 +30,46 @@ static integer c__5 = 5;
     void r_cnjg(complex *, complex *);
 
     /* Local variables */
-    static logical bads;
-    static integer isim;
-    static real temp;
-    static integer i, j;
-    extern /* Subroutine */ int cgerc_(integer *, integer *, complex *, 
-	    complex *, integer *, complex *, integer *, complex *, integer *);
+    static bool bads;
+    static int isim;
+    static float temp;
+    static int i, j;
+    extern /* Subroutine */ int cgerc_(int *, int *, complex *,
+	    complex *, int *, complex *, int *, complex *, int *);
     static complex alpha;
-    extern /* Subroutine */ int cscal_(integer *, complex *, complex *, 
-	    integer *);
-    extern /* Subroutine */ int cgemv_(char *, integer *, integer *, complex *
-	    , complex *, integer *, complex *, integer *, complex *, complex *
-	    , integer *);
-    static integer iinfo;
-    static real tempa[1];
-    static integer icols, idist;
-    extern /* Subroutine */ int ccopy_(integer *, complex *, integer *, 
-	    complex *, integer *);
-    static integer irows;
-    extern /* Subroutine */ int clatm1_(integer *, real *, integer *, integer 
-	    *, integer *, complex *, integer *, integer *), slatm1_slu(integer *,
-	     real *, integer *, integer *, integer *, real *, integer *, 
-	    integer *);
-    static integer ic, jc;
-    extern doublereal clange_(char *, integer *, integer *, complex *, 
-	    integer *, real *);
-    static integer ir;
-    extern /* Subroutine */ int clarge_slu(integer *, complex *, integer *, 
-	    integer *, complex *, integer *), clarfg_(integer *, complex *, 
-	    complex *, integer *, complex *), clacgv_slu(integer *, complex *, 
-	    integer *);
-    extern /* Complex */ VOID clarnd_slu(complex *, integer *, integer *);
-    static real ralpha;
-    extern /* Subroutine */ int csscal_(integer *, real *, complex *, integer 
-	    *), claset_slu(char *, integer *, integer *, complex *, complex *, 
-	    complex *, integer *),
-	     clarnv_slu(integer *, integer *, integer *, complex *);
+    extern /* Subroutine */ int cscal_(int *, complex *, complex *,
+	    int *);
+    extern /* Subroutine */ int cgemv_(char *, int *, int *, complex *
+	    , complex *, int *, complex *, int *, complex *, complex *
+	    , int *);
+    static int iinfo;
+    static float tempa[1];
+    static int icols, idist;
+    extern /* Subroutine */ int ccopy_(int *, complex *, int *,
+	    complex *, int *);
+    static int irows;
+    extern /* Subroutine */ int clatm1_(int *, float *, int *, int
+	    *, int *, complex *, int *, int *), slatm1_slu(int *,
+	     float *, int *, int *, int *, float *, int *,
+	    int *);
+    static int ic, jc;
+    extern double clange_(char *, int *, int *, complex *,
+	    int *, float *);
+    static int ir;
+    extern /* Subroutine */ int clarge_slu(int *, complex *, int *,
+	    int *, complex *, int *), clarfg_(int *, complex *,
+	    complex *, int *, complex *), clacgv_slu(int *, complex *,
+	    int *);
+    extern /* Complex */ void clarnd_slu(complex *, int *, int *);
+    static float ralpha;
+    extern /* Subroutine */ int csscal_(int *, float *, complex *, int
+	    *), claset_slu(char *, int *, int *, complex *, complex *,
+	    complex *, int *),
+	     clarnv_slu(int *, int *, int *, complex *);
     extern int input_error(char *, int *);
-    static integer irsign, iupper;
+    static int irsign, iupper;
     static complex xnorms;
-    static integer jcr;
+    static int jcr;
     static complex tau;
 
 
@@ -350,12 +351,12 @@ static integer c__5 = 5;
 
 /*     Check DS, if MODES=0 and ISIM=1 */
 
-    bads = FALSE_;
+    bads = false;
     if (*modes == 0 && isim == 1) {
 	i__1 = *n;
 	for (j = 1; j <= i__1; ++j) {
 	    if (ds[j] == 0.f) {
-		bads = TRUE_;
+		bads = true;
 	    }
 /* L10: */
 	}
@@ -387,7 +388,7 @@ static integer c__5 = 5;
 	*info = -15;
     } else if (*ku < 1 || *ku < *n - 1 && *kl < *n - 1) {
 	*info = -16;
-    } else if (*lda < max(1,*n)) {
+    } else if (*lda < SUPERLU_MAX(1,*n)) {
 	*info = -19;
     }
 
@@ -426,7 +427,7 @@ static integer c__5 = 5;
 	for (i = 2; i <= i__1; ++i) {
 /* Computing MAX */
 	    r__1 = temp, r__2 = c_abs(&d[i]);
-	    temp = dmax(r__1,r__2);
+	    temp = fmax(r__1,r__2);
 /* L30: */
 	}
 
@@ -530,14 +531,14 @@ static integer c__5 = 5;
 
 	    cgemv_("C", &irows, &icols, &c_b2, &a[jcr + (ic + 1) * a_dim1], 
 		    lda, &work[1], &c__1, &c_b1, &work[irows + 1], &c__1);
-	    q__1.r = -(doublereal)tau.r, q__1.i = -(doublereal)tau.i;
+	    q__1.r = -(double)tau.r, q__1.i = -(double)tau.i;
 	    cgerc_(&irows, &icols, &q__1, &work[1], &c__1, &work[irows + 1], &
 		    c__1, &a[jcr + (ic + 1) * a_dim1], lda);
 
 	    cgemv_("N", n, &irows, &c_b2, &a[jcr * a_dim1 + 1], lda, &work[1],
 		     &c__1, &c_b1, &work[irows + 1], &c__1);
 	    r_cnjg(&q__2, &tau);
-	    q__1.r = -(doublereal)q__2.r, q__1.i = -(doublereal)q__2.i;
+	    q__1.r = -(double)q__2.r, q__1.i = -(double)q__2.i;
 	    cgerc_(n, &irows, &q__1, &work[irows + 1], &c__1, &work[1], &c__1,
 		     &a[jcr * a_dim1 + 1], lda);
 
@@ -576,14 +577,14 @@ static integer c__5 = 5;
 
 	    cgemv_("N", &irows, &icols, &c_b2, &a[ir + 1 + jcr * a_dim1], lda,
 		     &work[1], &c__1, &c_b1, &work[icols + 1], &c__1);
-	    q__1.r = -(doublereal)tau.r, q__1.i = -(doublereal)tau.i;
+	    q__1.r = -(double)tau.r, q__1.i = -(double)tau.i;
 	    cgerc_(&irows, &icols, &q__1, &work[icols + 1], &c__1, &work[1], &
 		    c__1, &a[ir + 1 + jcr * a_dim1], lda);
 
 	    cgemv_("C", &icols, n, &c_b2, &a[jcr + a_dim1], lda, &work[1], &
 		    c__1, &c_b1, &work[icols + 1], &c__1);
 	    r_cnjg(&q__2, &tau);
-	    q__1.r = -(doublereal)q__2.r, q__1.i = -(doublereal)q__2.i;
+	    q__1.r = -(double)q__2.r, q__1.i = -(double)q__2.i;
 	    cgerc_(&icols, n, &q__1, &work[1], &c__1, &work[icols + 1], &c__1,
 		     &a[jcr + a_dim1], lda);
 
