@@ -1,78 +1,79 @@
 /*  -- translated by f2c (version 19940927).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
 */
+#include <math.h>
+#include <stdbool.h>
+#include <stdlib.h>
 #include <string.h>
-#include "f2c.h"
+#include "../../SRC/slu_scomplex.h"
+#include "../../SRC/slu_sdefs.h"
 
 /* Table of constant values */
 
 static complex c_b1 = {0.f,0.f};
-static integer c__1 = 1;
-static integer c__5 = 5;
-static logical c_true = TRUE_;
-static logical c_false = FALSE_;
+static int c__1 = 1;
+static int c__5 = 5;
+static bool c_true = true;
+static bool c_false = false;
 
-/* Subroutine */ int clatms_slu(integer *m, integer *n, char *dist, integer *
-	iseed, char *sym, real *d, integer *mode, real *cond, real *dmax__, 
-	integer *kl, integer *ku, char *pack, complex *a, integer *lda, 
-	complex *work, integer *info)
+/* Subroutine */ int clatms_slu(int *m, int *n, char *dist, int *
+	iseed, char *sym, float *d, int *mode, float *cond, float *dmax__,
+	int *kl, int *ku, char *pack, complex *a, int *lda,
+	complex *work, int *info)
 {
     /* System generated locals */
-    integer a_dim1, a_offset, i__1, i__2, i__3, i__4, i__5, i__6;
-    real r__1, r__2, r__3;
-    doublereal d__1;
+    int a_dim1, a_offset, i__1, i__2, i__3, i__4, i__5, i__6;
+    float r__1, r__2, r__3;
+    double d__1;
     complex q__1, q__2, q__3;
-    logical L__1;
+    bool L__1;
 
     /* Builtin functions */
-    double cos(doublereal), sin(doublereal);
     void r_cnjg(complex *, complex *);
 
     /* Local variables */
-    static integer ilda, icol;
-    static real temp;
-    static logical csym;
-    static integer irow, isym;
+    static int ilda, icol;
+    static float temp;
+    static bool csym;
+    static int irow, isym;
     static complex c;
-    static integer i, j, k;
+    static int i, j, k;
     static complex s;
-    static real alpha, angle;
-    static integer ipack;
-    static real realc;
-    static integer ioffg;
-    static integer iinfo;
-    extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
+    static float alpha, angle;
+    static int ipack;
+    static float floatc;
+    static int ioffg;
+    static int iinfo;
+    extern /* Subroutine */ int sscal_(int *, float *, float *, int *);
     static complex ctemp;
-    static integer idist, mnmin, iskew;
+    static int idist, mnmin, iskew;
     static complex extra, dummy;
-    extern /* Subroutine */ int slatm1_slu(integer *, real *, integer *, integer 
-	    *, integer *, real *, integer *, integer *);
-    static integer ic, jc, nc;
-    extern /* Subroutine */ int clagge_slu(integer *, integer *, integer *, 
-	    integer *, real *, complex *, integer *, integer *, complex *, 
-	    integer *), claghe_slu(integer *, integer *, real *, complex *, 
-	    integer *, integer *, complex *, integer *);
-    static integer il;
+    extern /* Subroutine */ int slatm1_slu(int *, float *, int *, int
+	    *, int *, float *, int *, int *);
+    static int ic, jc, nc;
+    extern /* Subroutine */ int clagge_slu(int *, int *, int *,
+	    int *, float *, complex *, int *, int *, complex *,
+	    int *), claghe_slu(int *, int *, float *, complex *,
+	    int *, int *, complex *, int *);
+    static int il;
     static complex ct;
-    static integer iendch, ir, jr, ipackg, mr;
-    extern /* Complex */ VOID clarnd_slu(complex *, integer *, integer *);
-    static integer minlda;
+    static int iendch, ir, jr, ipackg, mr;
+    extern /* Complex */ void clarnd_slu(complex *, int *, int *);
+    static int minlda;
     static complex st;
-    extern /* Subroutine */ int claset_slu(char *, integer *, integer *, complex 
-	    *, complex *, complex *, integer *), clartg_slu(complex *, 
-	    complex *, real *, complex *, complex *), 
-	    clagsy_slu(integer *, integer *, real *, complex *, 
-	    integer *, integer *, complex *, integer *);
+    extern /* Subroutine */ int claset_slu(char *, int *, int *, complex
+	    *, complex *, complex *, int *), clartg_slu(complex *,
+	    complex *, float *, complex *, complex *),
+	    clagsy_slu(int *, int *, float *, complex *,
+	    int *, int *, complex *, int *);
     extern int input_error(char *, int *);
-    extern doublereal slarnd_slu(integer *, integer *);
-    extern /* Subroutine */ int clarot_slu(logical *, logical *, logical *, 
-	    integer *, complex *, complex *, complex *, integer *, complex *, 
+    extern double slarnd_slu(int *, int *);
+    extern /* Subroutine */ int clarot_slu(bool *, bool *, bool *,
+	    int *, complex *, complex *, complex *, int *, complex *,
 	    complex *);
-    static logical iltemp, givens;
-    static integer ioffst, irsign;
-    static logical ilextr, topdwn;
-    static integer ir1, ir2, isympk, jch, llb, jkl, jku, uub;
+    static bool iltemp, givens;
+    static int ioffst, irsign;
+    static bool ilextr, topdwn;
+    static int ir1, ir2, isympk, jch, llb, jkl, jku, uub;
 
 
 /*  -- LAPACK test routine (version 2.0) --   
@@ -383,19 +384,19 @@ static logical c_false = FALSE_;
     if (strncmp(sym, "N", 1)==0) {
 	isym = 1;
 	irsign = 0;
-	csym = FALSE_;
+	csym = false;
     } else if (strncmp(sym, "P", 1)==0) {
 	isym = 2;
 	irsign = 0;
-	csym = FALSE_;
+	csym = false;
     } else if (strncmp(sym, "S", 1)==0) {
 	isym = 2;
 	irsign = 0;
-	csym = TRUE_;
+	csym = true;
     } else if (strncmp(sym, "H", 1)==0) {
 	isym = 2;
 	irsign = 1;
-	csym = FALSE_;
+	csym = false;
     } else {
 	isym = -1;
     }
@@ -431,19 +432,19 @@ static logical c_false = FALSE_;
 
 /*     Set certain internal parameters */
 
-    mnmin = min(*m,*n);
+    mnmin = SUPERLU_MIN(*m,*n);
 /* Computing MIN */
     i__1 = *kl, i__2 = *m - 1;
-    llb = min(i__1,i__2);
+    llb = SUPERLU_MIN(i__1,i__2);
 /* Computing MIN */
     i__1 = *ku, i__2 = *n - 1;
-    uub = min(i__1,i__2);
+    uub = SUPERLU_MIN(i__1,i__2);
 /* Computing MIN */
     i__1 = *m, i__2 = *n + llb;
-    mr = min(i__1,i__2);
+    mr = SUPERLU_MIN(i__1,i__2);
 /* Computing MIN */
     i__1 = *n, i__2 = *m + uub;
-    nc = min(i__1,i__2);
+    nc = SUPERLU_MIN(i__1,i__2);
 
     if (ipack == 5 || ipack == 6) {
 	minlda = uub + 1;
@@ -456,20 +457,20 @@ static logical c_false = FALSE_;
 /*     Use Givens rotation method if bandwidth small enough,   
        or if LDA is too small to store the matrix unpacked. */
 
-    givens = FALSE_;
+    givens = false;
     if (isym == 1) {
 /* Computing MAX */
 	i__1 = 1, i__2 = mr + nc;
-	if ((real) (llb + uub) < (real) max(i__1,i__2) * .3f) {
-	    givens = TRUE_;
+	if ((float) (llb + uub) < (float) SUPERLU_MAX(i__1,i__2) * .3f) {
+	    givens = true;
 	}
     } else {
 	if (llb << 1 < *m) {
-	    givens = TRUE_;
+	    givens = true;
 	}
     }
     if (*lda < *m && *lda >= minlda) {
-	givens = TRUE_;
+	givens = true;
     }
 
 /*     Set INFO if an error */
@@ -497,7 +498,7 @@ static logical c_false = FALSE_;
 		(isympk == 3 && isym == 1 && *ku > 0) ||
 		(isympk != 0 && *m != *n) ) {
 	*info = -12;
-    } else if (*lda < max(1,minlda)) {
+    } else if (*lda < SUPERLU_MAX(1,minlda)) {
 	*info = -14;
     }
 
@@ -531,22 +532,22 @@ static logical c_false = FALSE_;
 /*     Choose Top-Down if D is (apparently) increasing,   
        Bottom-Up if D is (apparently) decreasing. */
 
-    if (dabs(d[1]) <= (r__1 = d[mnmin], dabs(r__1))) {
-	topdwn = TRUE_;
+    if (fabs(d[1]) <= (r__1 = d[mnmin], fabs(r__1))) {
+	topdwn = true;
     } else {
-	topdwn = FALSE_;
+	topdwn = false;
     }
 
     if (*mode != 0 && abs(*mode) != 6) {
 
 /*        Scale by DMAX */
 
-	temp = dabs(d[1]);
+	temp = fabs(d[1]);
 	i__1 = mnmin;
 	for (i = 2; i <= i__1; ++i) {
 /* Computing MAX */
-	    r__2 = temp, r__3 = (r__1 = d[i], dabs(r__1));
-	    temp = dmax(r__2,r__3);
+	    r__2 = temp, r__3 = (r__1 = d[i], fabs(r__1));
+	    temp = fmax(r__2,r__3);
 /* L20: */
 	}
 
@@ -647,7 +648,7 @@ JKU, N )
 
    Computing MIN */
 		    i__3 = *m + jku;
-		    i__2 = min(i__3,*n) + jkl - 1;
+		    i__2 = SUPERLU_MIN(i__3,*n) + jkl - 1;
 		    for (jr = 1; jr <= i__2; ++jr) {
 			extra.r = 0.f, extra.i = 0.f;
 			angle = slarnd_slu(&c__1, &iseed[1]) * 
@@ -662,11 +663,11 @@ JKU, N )
 			s.r = q__1.r, s.i = q__1.i;
 /* Computing MAX */
 			i__3 = 1, i__4 = jr - jkl;
-			icol = max(i__3,i__4);
+			icol = SUPERLU_MAX(i__3,i__4);
 			if (jr < *m) {
 /* Computing MIN */
 			    i__3 = *n, i__4 = jr + jku;
-			    il = min(i__3,i__4) + 1 - icol;
+			    il = SUPERLU_MIN(i__3,i__4) + 1 - icol;
 			    L__1 = jr > jkl;
 			    clarot_slu(&c_true, &L__1, &c_false, &il, &c, &s, &a[
 				    jr - iskew * icol + ioffst + icol * 
@@ -682,16 +683,16 @@ JKU, N )
 				jch += i__3) {
 			    if (ir < *m) {
 				clartg_slu(&a[ir + 1 - iskew * (ic + 1) + ioffst 
-					+ (ic + 1) * a_dim1], &extra, &realc, 
+					+ (ic + 1) * a_dim1], &extra, &floatc,
 					&s, &dummy);
 				clarnd_slu(&q__1, &c__5, &iseed[1]);
 				dummy.r = q__1.r, dummy.i = q__1.i;
-				q__2.r = realc * dummy.r, q__2.i = realc * 
+				q__2.r = floatc * dummy.r, q__2.i = floatc *
 					dummy.i;
 				r_cnjg(&q__1, &q__2);
 				c.r = q__1.r, c.i = q__1.i;
-				q__3.r = -(doublereal)s.r, q__3.i = -(
-					doublereal)s.i;
+				q__3.r = -(double)s.r, q__3.i = -(
+					double)s.i;
 				q__2.r = q__3.r * dummy.r - q__3.i * dummy.i, 
 					q__2.i = q__3.r * dummy.i + q__3.i * 
 					dummy.r;
@@ -700,7 +701,7 @@ JKU, N )
 			    }
 /* Computing MAX */
 			    i__4 = 1, i__5 = jch - jku;
-			    irow = max(i__4,i__5);
+			    irow = SUPERLU_MAX(i__4,i__5);
 			    il = ir + 2 - irow;
 			    ctemp.r = 0.f, ctemp.i = 0.f;
 			    iltemp = jch > jku;
@@ -710,15 +711,15 @@ JKU, N )
 			    if (iltemp) {
 				clartg_slu(&a[irow + 1 - iskew * (ic + 1) + 
 					ioffst + (ic + 1) * a_dim1], &ctemp, &
-					realc, &s, &dummy);
+					floatc, &s, &dummy);
 				clarnd_slu(&q__1, &c__5, &iseed[1]);
 				dummy.r = q__1.r, dummy.i = q__1.i;
-				q__2.r = realc * dummy.r, q__2.i = realc * 
+				q__2.r = floatc * dummy.r, q__2.i = floatc *
 					dummy.i;
 				r_cnjg(&q__1, &q__2);
 				c.r = q__1.r, c.i = q__1.i;
-				q__3.r = -(doublereal)s.r, q__3.i = -(
-					doublereal)s.i;
+				q__3.r = -(double)s.r, q__3.i = -(
+					double)s.i;
 				q__2.r = q__3.r * dummy.r - q__3.i * dummy.i, 
 					q__2.i = q__3.r * dummy.i + q__3.i * 
 					dummy.r;
@@ -727,7 +728,7 @@ JKU, N )
 
 /* Computing MAX */
 				i__4 = 1, i__5 = jch - jku - jkl;
-				icol = max(i__4,i__5);
+				icol = SUPERLU_MAX(i__4,i__5);
 				il = ic + 2 - icol;
 				extra.r = 0.f, extra.i = 0.f;
 				L__1 = jch > jku + jkl;
@@ -754,7 +755,7 @@ JKL, JKU
 
    Computing MIN */
 		    i__3 = *n + jkl;
-		    i__2 = min(i__3,*m) + jku - 1;
+		    i__2 = SUPERLU_MIN(i__3,*m) + jku - 1;
 		    for (jc = 1; jc <= i__2; ++jc) {
 			extra.r = 0.f, extra.i = 0.f;
 			angle = slarnd_slu(&c__1, &iseed[1]) * 
@@ -769,11 +770,11 @@ JKL, JKU
 			s.r = q__1.r, s.i = q__1.i;
 /* Computing MAX */
 			i__3 = 1, i__4 = jc - jku;
-			irow = max(i__3,i__4);
+			irow = SUPERLU_MAX(i__3,i__4);
 			if (jc < *n) {
 /* Computing MIN */
 			    i__3 = *m, i__4 = jc + jkl;
-			    il = min(i__3,i__4) + 1 - irow;
+			    il = SUPERLU_MIN(i__3,i__4) + 1 - irow;
 			    L__1 = jc > jku;
 			    clarot_slu(&c_false, &L__1, &c_false, &il, &c, &s, &
 				    a[irow - iskew * jc + ioffst + jc * 
@@ -789,16 +790,16 @@ JKL, JKU
 				jch += i__3) {
 			    if (ic < *n) {
 				clartg_slu(&a[ir + 1 - iskew * (ic + 1) + ioffst 
-					+ (ic + 1) * a_dim1], &extra, &realc, 
+					+ (ic + 1) * a_dim1], &extra, &floatc,
 					&s, &dummy);
 				clarnd_slu(&q__1, &c__5, &iseed[1]);
 				dummy.r = q__1.r, dummy.i = q__1.i;
-				q__2.r = realc * dummy.r, q__2.i = realc * 
+				q__2.r = floatc * dummy.r, q__2.i = floatc *
 					dummy.i;
 				r_cnjg(&q__1, &q__2);
 				c.r = q__1.r, c.i = q__1.i;
-				q__3.r = -(doublereal)s.r, q__3.i = -(
-					doublereal)s.i;
+				q__3.r = -(double)s.r, q__3.i = -(
+					double)s.i;
 				q__2.r = q__3.r * dummy.r - q__3.i * dummy.i, 
 					q__2.i = q__3.r * dummy.i + q__3.i * 
 					dummy.r;
@@ -807,7 +808,7 @@ JKL, JKU
 			    }
 /* Computing MAX */
 			    i__4 = 1, i__5 = jch - jkl;
-			    icol = max(i__4,i__5);
+			    icol = SUPERLU_MAX(i__4,i__5);
 			    il = ic + 2 - icol;
 			    ctemp.r = 0.f, ctemp.i = 0.f;
 			    iltemp = jch > jkl;
@@ -817,15 +818,15 @@ JKL, JKU
 			    if (iltemp) {
 				clartg_slu(&a[ir + 1 - iskew * (icol + 1) + 
 					ioffst + (icol + 1) * a_dim1], &ctemp,
-					 &realc, &s, &dummy);
+					 &floatc, &s, &dummy);
 				clarnd_slu(&q__1, &c__5, &iseed[1]);
 				dummy.r = q__1.r, dummy.i = q__1.i;
-				q__2.r = realc * dummy.r, q__2.i = realc * 
+				q__2.r = floatc * dummy.r, q__2.i = floatc *
 					dummy.i;
 				r_cnjg(&q__1, &q__2);
 				c.r = q__1.r, c.i = q__1.i;
-				q__3.r = -(doublereal)s.r, q__3.i = -(
-					doublereal)s.i;
+				q__3.r = -(double)s.r, q__3.i = -(
+					double)s.i;
 				q__2.r = q__3.r * dummy.r - q__3.i * dummy.i, 
 					q__2.i = q__3.r * dummy.i + q__3.i * 
 					dummy.r;
@@ -833,7 +834,7 @@ JKL, JKU
 				s.r = q__1.r, s.i = q__1.i;
 /* Computing MAX */
 				i__4 = 1, i__5 = jch - jkl - jku;
-				irow = max(i__4,i__5);
+				irow = SUPERLU_MAX(i__4,i__5);
 				il = ir + 2 - irow;
 				extra.r = 0.f, extra.i = 0.f;
 				L__1 = jch > jkl + jku;
@@ -868,11 +869,11 @@ JKL, JKU
 
    Computing MIN */
 		    i__2 = *m, i__3 = *n + jkl;
-		    iendch = min(i__2,i__3) - 1;
+		    iendch = SUPERLU_MIN(i__2,i__3) - 1;
 /* Computing MIN */
 		    i__2 = *m + jku;
 		    i__3 = 1 - jkl;
-		    for (jc = min(i__2,*n) - 1; jc >= i__3; --jc) {
+		    for (jc = SUPERLU_MIN(i__2,*n) - 1; jc >= i__3; --jc) {
 			extra.r = 0.f, extra.i = 0.f;
 			angle = slarnd_slu(&c__1, &iseed[1]) * 
 				6.2831853071795864769252867663f;
@@ -886,11 +887,11 @@ JKL, JKU
 			s.r = q__1.r, s.i = q__1.i;
 /* Computing MAX */
 			i__2 = 1, i__4 = jc - jku + 1;
-			irow = max(i__2,i__4);
+			irow = SUPERLU_MAX(i__2,i__4);
 			if (jc > 0) {
 /* Computing MIN */
 			    i__2 = *m, i__4 = jc + jkl + 1;
-			    il = min(i__2,i__4) + 1 - irow;
+			    il = SUPERLU_MIN(i__2,i__4) + 1 - irow;
 			    L__1 = jc + jkl < *m;
 			    clarot_slu(&c_false, &c_false, &L__1, &il, &c, &s, &
 				    a[irow - iskew * jc + ioffst + jc * 
@@ -907,10 +908,10 @@ JKL, JKU
 			    ilextr = ic > 0;
 			    if (ilextr) {
 				clartg_slu(&a[jch - iskew * ic + ioffst + ic * 
-					a_dim1], &extra, &realc, &s, &dummy);
+					a_dim1], &extra, &floatc, &s, &dummy);
 				clarnd_slu(&q__1, &c__5, &iseed[1]);
 				dummy.r = q__1.r, dummy.i = q__1.i;
-				q__1.r = realc * dummy.r, q__1.i = realc * 
+				q__1.r = floatc * dummy.r, q__1.i = floatc *
 					dummy.i;
 				c.r = q__1.r, c.i = q__1.i;
 				q__1.r = s.r * dummy.r - s.i * dummy.i, 
@@ -918,10 +919,10 @@ JKL, JKU
 					dummy.r;
 				s.r = q__1.r, s.i = q__1.i;
 			    }
-			    ic = max(1,ic);
+			    ic = SUPERLU_MAX(1,ic);
 /* Computing MIN */
 			    i__5 = *n - 1, i__6 = jch + jku;
-			    icol = min(i__5,i__6);
+			    icol = SUPERLU_MIN(i__5,i__6);
 			    iltemp = jch + jku < *n;
 			    ctemp.r = 0.f, ctemp.i = 0.f;
 			    i__5 = icol + 2 - ic;
@@ -930,11 +931,11 @@ JKL, JKU
 				    a_dim1], &ilda, &extra, &ctemp);
 			    if (iltemp) {
 				clartg_slu(&a[jch - iskew * icol + ioffst + icol 
-					* a_dim1], &ctemp, &realc, &s, &dummy)
+					* a_dim1], &ctemp, &floatc, &s, &dummy)
 					;
 				clarnd_slu(&q__1, &c__5, &iseed[1]);
 				dummy.r = q__1.r, dummy.i = q__1.i;
-				q__1.r = realc * dummy.r, q__1.i = realc * 
+				q__1.r = floatc * dummy.r, q__1.i = floatc *
 					dummy.i;
 				c.r = q__1.r, c.i = q__1.i;
 				q__1.r = s.r * dummy.r - s.i * dummy.i, 
@@ -943,7 +944,7 @@ JKL, JKU
 				s.r = q__1.r, s.i = q__1.i;
 /* Computing MIN */
 				i__5 = iendch, i__6 = jch + jkl + jku;
-				il = min(i__5,i__6) + 2 - jch;
+				il = SUPERLU_MIN(i__5,i__6) + 2 - jch;
 				extra.r = 0.f, extra.i = 0.f;
 				L__1 = jch + jkl + jku <= iendch;
 				clarot_slu(&c_false, &c_true, &L__1, &il, &c, &s,
@@ -972,11 +973,11 @@ L, M )
 
    Computing MIN */
 		    i__3 = *n, i__4 = *m + jku;
-		    iendch = min(i__3,i__4) - 1;
+		    iendch = SUPERLU_MIN(i__3,i__4) - 1;
 /* Computing MIN */
 		    i__3 = *n + jkl;
 		    i__4 = 1 - jku;
-		    for (jr = min(i__3,*m) - 1; jr >= i__4; --jr) {
+		    for (jr = SUPERLU_MIN(i__3,*m) - 1; jr >= i__4; --jr) {
 			extra.r = 0.f, extra.i = 0.f;
 			angle = slarnd_slu(&c__1, &iseed[1]) * 
 				6.2831853071795864769252867663f;
@@ -990,11 +991,11 @@ L, M )
 			s.r = q__1.r, s.i = q__1.i;
 /* Computing MAX */
 			i__3 = 1, i__2 = jr - jkl + 1;
-			icol = max(i__3,i__2);
+			icol = SUPERLU_MAX(i__3,i__2);
 			if (jr > 0) {
 /* Computing MIN */
 			    i__3 = *n, i__2 = jr + jku + 1;
-			    il = min(i__3,i__2) + 1 - icol;
+			    il = SUPERLU_MIN(i__3,i__2) + 1 - icol;
 			    L__1 = jr + jku < *n;
 			    clarot_slu(&c_true, &c_false, &L__1, &il, &c, &s, &a[
 				    jr - iskew * icol + ioffst + icol * 
@@ -1011,10 +1012,10 @@ L, M )
 			    ilextr = ir > 0;
 			    if (ilextr) {
 				clartg_slu(&a[ir - iskew * jch + ioffst + jch * 
-					a_dim1], &extra, &realc, &s, &dummy);
+					a_dim1], &extra, &floatc, &s, &dummy);
 				clarnd_slu(&q__1, &c__5, &iseed[1]);
 				dummy.r = q__1.r, dummy.i = q__1.i;
-				q__1.r = realc * dummy.r, q__1.i = realc * 
+				q__1.r = floatc * dummy.r, q__1.i = floatc *
 					dummy.i;
 				c.r = q__1.r, c.i = q__1.i;
 				q__1.r = s.r * dummy.r - s.i * dummy.i, 
@@ -1022,10 +1023,10 @@ L, M )
 					dummy.r;
 				s.r = q__1.r, s.i = q__1.i;
 			    }
-			    ir = max(1,ir);
+			    ir = SUPERLU_MAX(1,ir);
 /* Computing MIN */
 			    i__5 = *m - 1, i__6 = jch + jkl;
-			    irow = min(i__5,i__6);
+			    irow = SUPERLU_MIN(i__5,i__6);
 			    iltemp = jch + jkl < *m;
 			    ctemp.r = 0.f, ctemp.i = 0.f;
 			    i__5 = irow + 2 - ir;
@@ -1034,10 +1035,10 @@ L, M )
 				    a_dim1], &ilda, &extra, &ctemp);
 			    if (iltemp) {
 				clartg_slu(&a[irow - iskew * jch + ioffst + jch *
-					 a_dim1], &ctemp, &realc, &s, &dummy);
+					 a_dim1], &ctemp, &floatc, &s, &dummy);
 				clarnd_slu(&q__1, &c__5, &iseed[1]);
 				dummy.r = q__1.r, dummy.i = q__1.i;
-				q__1.r = realc * dummy.r, q__1.i = realc * 
+				q__1.r = floatc * dummy.r, q__1.i = floatc *
 					dummy.i;
 				c.r = q__1.r, c.i = q__1.i;
 				q__1.r = s.r * dummy.r - s.i * dummy.i, 
@@ -1046,7 +1047,7 @@ L, M )
 				s.r = q__1.r, s.i = q__1.i;
 /* Computing MIN */
 				i__5 = iendch, i__6 = jch + jkl + jku;
-				il = min(i__5,i__6) + 2 - jch;
+				il = SUPERLU_MIN(i__5,i__6) + 2 - jch;
 				extra.r = 0.f, extra.i = 0.f;
 				L__1 = jch + jkl + jku <= iendch;
 				clarot_slu(&c_true, &c_true, &L__1, &il, &c, &s, 
@@ -1097,10 +1098,10 @@ L, M )
 		    for (jc = 1; jc <= i__4; ++jc) {
 /* Computing MAX */
 			i__2 = 1, i__3 = jc - k;
-			irow = max(i__2,i__3);
+			irow = SUPERLU_MAX(i__2,i__3);
 /* Computing MIN */
 			i__2 = jc + 1, i__3 = k + 2;
-			il = min(i__2,i__3);
+			il = SUPERLU_MIN(i__2,i__3);
 			extra.r = 0.f, extra.i = 0.f;
 			i__2 = jc - iskew * (jc + 1) + ioffg + (jc + 1) * 
 				a_dim1;
@@ -1132,7 +1133,7 @@ L, M )
 				ilda, &extra, &ctemp);
 /* Computing MIN */
 			i__3 = k, i__5 = *n - jc;
-			i__2 = min(i__3,i__5) + 1;
+			i__2 = SUPERLU_MIN(i__3,i__5) + 1;
 			clarot_slu(&c_true, &c_true, &c_false, &i__2, &ct, &st, &
 				a[(1 - iskew) * jc + ioffg + jc * a_dim1], &
 				ilda, &ctemp, &dummy);
@@ -1145,15 +1146,14 @@ L, M )
 			for (jch = jc - k; i__2 < 0 ? jch >= 1 : jch <= 1; 
 				jch += i__2) {
 			    clartg_slu(&a[jch + 1 - iskew * (icol + 1) + ioffg + 
-				    (icol + 1) * a_dim1], &extra, &realc, &s, 
-				    &dummy);
+				    (icol + 1) * a_dim1], &extra, &floatc, &s, &dummy);
 			    clarnd_slu(&q__1, &c__5, &iseed[1]);
 			    dummy.r = q__1.r, dummy.i = q__1.i;
-			    q__2.r = realc * dummy.r, q__2.i = realc * 
+			    q__2.r = floatc * dummy.r, q__2.i = floatc *
 				    dummy.i;
 			    r_cnjg(&q__1, &q__2);
 			    c.r = q__1.r, c.i = q__1.i;
-			    q__3.r = -(doublereal)s.r, q__3.i = -(doublereal)
+			    q__3.r = -(double)s.r, q__3.i = -(double)
 				    s.i;
 			    q__2.r = q__3.r * dummy.r - q__3.i * dummy.i, 
 				    q__2.i = q__3.r * dummy.i + q__3.i * 
@@ -1180,10 +1180,10 @@ L, M )
 				    a_dim1], &ilda, &ctemp, &extra);
 /* Computing MAX */
 			    i__3 = 1, i__5 = jch - k;
-			    irow = max(i__3,i__5);
+			    irow = SUPERLU_MAX(i__3,i__5);
 /* Computing MIN */
 			    i__3 = jch + 1, i__5 = k + 2;
-			    il = min(i__3,i__5);
+			    il = SUPERLU_MIN(i__3,i__5);
 			    extra.r = 0.f, extra.i = 0.f;
 			    L__1 = jch > k;
 			    clarot_slu(&c_false, &L__1, &c_true, &il, &ct, &st, &
@@ -1209,7 +1209,7 @@ te that
 			if (csym) {
 /* Computing MIN */
 			    i__2 = *n, i__3 = jc + uub;
-			    i__4 = min(i__2,i__3);
+			    i__4 = SUPERLU_MIN(i__2,i__3);
 			    for (jr = jc; jr <= i__4; ++jr) {
 				i__2 = jr + irow + jc * a_dim1;
 				i__3 = jc - iskew * jr + ioffg + jr * a_dim1;
@@ -1219,7 +1219,7 @@ te that
 			} else {
 /* Computing MIN */
 			    i__2 = *n, i__3 = jc + uub;
-			    i__4 = min(i__2,i__3);
+			    i__4 = SUPERLU_MIN(i__2,i__3);
 			    for (jr = jc; jr <= i__4; ++jr) {
 				i__2 = jr + irow + jc * a_dim1;
 				r_cnjg(&q__1, &a[jc - iskew * jr + ioffg + jr 
@@ -1275,7 +1275,7 @@ te that
 		    for (jc = *n - 1; jc >= 1; --jc) {
 /* Computing MIN */
 			i__4 = *n + 1 - jc, i__2 = k + 2;
-			il = min(i__4,i__2);
+			il = SUPERLU_MIN(i__4,i__2);
 			extra.r = 0.f, extra.i = 0.f;
 			i__4 = (1 - iskew) * jc + 1 + ioffg + jc * a_dim1;
 			ctemp.r = a[i__4].r, ctemp.i = a[i__4].i;
@@ -1306,7 +1306,7 @@ te that
 				ctemp, &extra);
 /* Computing MAX */
 			i__4 = 1, i__2 = jc - k + 1;
-			icol = max(i__4,i__2);
+			icol = SUPERLU_MAX(i__4,i__2);
 			i__4 = jc + 2 - icol;
 			clarot_slu(&c_true, &c_false, &c_true, &i__4, &ct, &st, &
 				a[jc - iskew * icol + ioffg + icol * a_dim1], 
@@ -1321,10 +1321,10 @@ te that
 			for (jch = jc + k; i__2 < 0 ? jch >= i__4 : jch <= 
 				i__4; jch += i__2) {
 			    clartg_slu(&a[jch - iskew * icol + ioffg + icol * 
-				    a_dim1], &extra, &realc, &s, &dummy);
+				    a_dim1], &extra, &floatc, &s, &dummy);
 			    clarnd_slu(&q__1, &c__5, &iseed[1]);
 			    dummy.r = q__1.r, dummy.i = q__1.i;
-			    q__1.r = realc * dummy.r, q__1.i = realc * 
+			    q__1.r = floatc * dummy.r, q__1.i = floatc *
 				    dummy.i;
 			    c.r = q__1.r, c.i = q__1.i;
 			    q__1.r = s.r * dummy.r - s.i * dummy.i, q__1.i = 
@@ -1350,7 +1350,7 @@ te that
 				    a_dim1], &ilda, &extra, &ctemp);
 /* Computing MIN */
 			    i__3 = *n + 1 - jch, i__5 = k + 2;
-			    il = min(i__3,i__5);
+			    il = SUPERLU_MIN(i__3,i__5);
 			    extra.r = 0.f, extra.i = 0.f;
 			    L__1 = *n - jch > k;
 			    clarot_slu(&c_false, &c_true, &L__1, &il, &ct, &st, &
@@ -1375,7 +1375,7 @@ te that
 			if (csym) {
 /* Computing MAX */
 			    i__2 = 1, i__4 = jc - uub;
-			    i__1 = max(i__2,i__4);
+			    i__1 = SUPERLU_MAX(i__2,i__4);
 			    for (jr = jc; jr >= i__1; --jr) {
 				i__2 = jr + irow + jc * a_dim1;
 				i__4 = jc - iskew * jr + ioffg + jr * a_dim1;
@@ -1385,7 +1385,7 @@ te that
 			} else {
 /* Computing MAX */
 			    i__2 = 1, i__4 = jc - uub;
-			    i__1 = max(i__2,i__4);
+			    i__1 = SUPERLU_MAX(i__2,i__4);
 			    for (jr = jc; jr >= i__1; --jr) {
 				i__2 = jr + irow + jc * a_dim1;
 				r_cnjg(&q__1, &a[jc - iskew * jr + ioffg + jr 
@@ -1567,7 +1567,7 @@ te that
 	    for (j = 1; j <= i__1; ++j) {
 /* Computing MIN */
 		i__2 = j + llb;
-		for (i = min(i__2,*m); i >= 1; --i) {
+		for (i = SUPERLU_MIN(i__2,*m); i >= 1; --i) {
 		    i__2 = i - j + uub + 1 + j * a_dim1;
 		    i__4 = i + j * a_dim1;
 		    a[i__2].r = a[i__4].r, a[i__2].i = a[i__4].i;
@@ -1580,7 +1580,7 @@ te that
 	    for (j = uub + 2; j <= i__1; ++j) {
 /* Computing MIN */
 		i__4 = j + llb;
-		i__2 = min(i__4,*m);
+		i__2 = SUPERLU_MIN(i__4,*m);
 		for (i = j - uub; i <= i__2; ++i) {
 		    i__4 = i - j + uub + 1 + j * a_dim1;
 		    i__3 = i + j * a_dim1;
@@ -1631,9 +1631,9 @@ te that
 /* Computing MAX   
    Computing MIN */
 		i__3 = ir1, i__5 = ir2 - jc;
-		i__2 = 1, i__4 = min(i__3,i__5);
+		i__2 = 1, i__4 = SUPERLU_MIN(i__3,i__5);
 		i__6 = *lda;
-		for (jr = max(i__2,i__4); jr <= i__6; ++jr) {
+		for (jr = SUPERLU_MAX(i__2,i__4); jr <= i__6; ++jr) {
 		    i__2 = jr + jc * a_dim1;
 		    a[i__2].r = 0.f, a[i__2].i = 0.f;
 /* L510: */
