@@ -1,81 +1,82 @@
 /*  -- translated by f2c (version 19940927).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
 */
+#include <math.h>
+#include <stdbool.h>
+#include <stdlib.h>
 #include <string.h>
-#include "f2c.h"
+#include "../../SRC/slu_dcomplex.h"
+#include "../../SRC/slu_ddefs.h"
 
 /* Table of constant values */
 
 static doublecomplex c_b1 = {0.,0.};
-static integer c__1 = 1;
-static integer c__5 = 5;
-static logical c_true = TRUE_;
-static logical c_false = FALSE_;
+static int c__1 = 1;
+static int c__5 = 5;
+static bool c_true = true;
+static bool c_false = false;
 
-/* Subroutine */ int zlatms_slu(integer *m, integer *n, char *dist, integer *
-	iseed, char *sym, doublereal *d, integer *mode, doublereal *cond, 
-	doublereal *dmax__, integer *kl, integer *ku, char *pack, 
-	doublecomplex *a, integer *lda, doublecomplex *work, integer *info)
+/* Subroutine */ int zlatms_slu(int *m, int *n, char *dist, int *
+	iseed, char *sym, double *d, int *mode, double *cond,
+	double *dmax__, int *kl, int *ku, char *pack,
+	doublecomplex *a, int *lda, doublecomplex *work, int *info)
 {
     /* System generated locals */
-    integer a_dim1, a_offset, i__1, i__2, i__3, i__4, i__5, i__6;
-    doublereal d__1, d__2, d__3;
+    int a_dim1, a_offset, i__1, i__2, i__3, i__4, i__5, i__6;
+    double d__1, d__2, d__3;
     doublecomplex z__1, z__2, z__3;
-    logical L__1;
+    bool L__1;
 
     /* Builtin functions */
-    double cos(doublereal), sin(doublereal);
     void d_cnjg(doublecomplex *, doublecomplex *);
 
     /* Local variables */
-    static integer ilda, icol;
-    static doublereal temp;
-    static integer irow, isym;
-    static logical zsym;
+    static int ilda, icol;
+    static double temp;
+    static int irow, isym;
+    static bool zsym;
     static doublecomplex c;
-    static integer i, j, k;
+    static int i, j, k;
     static doublecomplex s;
-    static doublereal alpha, angle;
-    static integer ipack;
-    static doublereal realc;
-    static integer ioffg;
-    extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
-	    integer *);
-    static integer iinfo;
+    static double alpha, angle;
+    static int ipack;
+    static double realc;
+    static int ioffg;
+    extern /* Subroutine */ int dscal_(int *, double *, double *,
+	    int *);
+    static int iinfo;
     static doublecomplex ctemp;
-    static integer idist, mnmin, iskew;
+    static int idist, mnmin, iskew;
     static doublecomplex extra, dummy;
-    extern /* Subroutine */ int dlatm1_slu(integer *, doublereal *, integer *, 
-	    integer *, integer *, doublereal *, integer *, integer *);
-    static integer ic, jc, nc, il;
+    extern /* Subroutine */ int dlatm1_slu(int *, double *, int *,
+	    int *, int *, double *, int *, int *);
+    static int ic, jc, nc, il;
     static doublecomplex ct;
-    static integer iendch, ir, jr, ipackg, mr, minlda;
-    extern doublereal dlarnd_slu(integer *, integer *);
+    static int iendch, ir, jr, ipackg, mr, minlda;
+    extern double dlarnd_slu(int *, int *);
     static doublecomplex st;
-    extern /* Subroutine */ int zlagge_slu(integer *, integer *, integer *, 
-	    integer *, doublereal *, doublecomplex *, integer *, integer *, 
-	    doublecomplex *, integer *), zlaghe_slu(integer *, integer *, 
-	    doublereal *, doublecomplex *, integer *, integer *, 
-						 doublecomplex *, integer *);
+    extern /* Subroutine */ int zlagge_slu(int *, int *, int *,
+	    int *, double *, doublecomplex *, int *, int *,
+	    doublecomplex *, int *), zlaghe_slu(int *, int *,
+	    double *, doublecomplex *, int *, int *,
+						 doublecomplex *, int *);
     extern int input_error(char *, int *);
-    static logical iltemp, givens;
-    static integer ioffst, irsign;
-    extern /* Double Complex */ void zlarnd_slu(doublecomplex *, integer *, 
-	    integer *);
-    extern /* Subroutine */ int zlaset_slu(char *, integer *, integer *, 
-	    doublecomplex *, doublecomplex *, doublecomplex *, integer *), zlartg_slu(doublecomplex *, doublecomplex *, doublereal *, 
+    static bool iltemp, givens;
+    static int ioffst, irsign;
+    extern /* Double Complex */ void zlarnd_slu(doublecomplex *, int *,
+	    int *);
+    extern /* Subroutine */ int zlaset_slu(char *, int *, int *,
+	    doublecomplex *, doublecomplex *, doublecomplex *, int *), zlartg_slu(doublecomplex *, doublecomplex *, double *,
 	    doublecomplex *, doublecomplex *);
-    static logical ilextr;
-    extern /* Subroutine */ int zlagsy_slu(integer *, integer *, doublereal *, 
-	    doublecomplex *, integer *, integer *, doublecomplex *, integer *)
+    static bool ilextr;
+    extern /* Subroutine */ int zlagsy_slu(int *, int *, double *,
+	    doublecomplex *, int *, int *, doublecomplex *, int *)
 	    ;
-    static logical topdwn;
-    static integer ir1, ir2, isympk;
-    extern /* Subroutine */ int zlarot_slu(logical *, logical *, logical *, 
-	    integer *, doublecomplex *, doublecomplex *, doublecomplex *, 
-	    integer *, doublecomplex *, doublecomplex *);
-    static integer jch, llb, jkl, jku, uub;
+    static bool topdwn;
+    static int ir1, ir2, isympk;
+    extern /* Subroutine */ int zlarot_slu(bool *, bool *, bool *,
+	    int *, doublecomplex *, doublecomplex *, doublecomplex *,
+	    int *, doublecomplex *, doublecomplex *);
+    static int jch, llb, jkl, jku, uub;
 
 
 /*  -- LAPACK test routine (version 2.0) --   
@@ -386,19 +387,19 @@ static logical c_false = FALSE_;
     if (strncmp(sym, "N", 1)==0) {
 	isym = 1;
 	irsign = 0;
-	zsym = FALSE_;
+	zsym = false;
     } else if (strncmp(sym, "P", 1)==0) {
 	isym = 2;
 	irsign = 0;
-	zsym = FALSE_;
+	zsym = false;
     } else if (strncmp(sym, "S", 1)==0) {
 	isym = 2;
 	irsign = 0;
-	zsym = TRUE_;
+	zsym = true;
     } else if (strncmp(sym, "H", 1)==0) {
 	isym = 2;
 	irsign = 1;
-	zsym = FALSE_;
+	zsym = false;
     } else {
 	isym = -1;
     }
@@ -434,19 +435,19 @@ static logical c_false = FALSE_;
 
 /*     Set certain internal parameters */
 
-    mnmin = min(*m,*n);
+    mnmin = SUPERLU_MIN(*m,*n);
 /* Computing MIN */
     i__1 = *kl, i__2 = *m - 1;
-    llb = min(i__1,i__2);
+    llb = SUPERLU_MIN(i__1,i__2);
 /* Computing MIN */
     i__1 = *ku, i__2 = *n - 1;
-    uub = min(i__1,i__2);
+    uub = SUPERLU_MIN(i__1,i__2);
 /* Computing MIN */
     i__1 = *m, i__2 = *n + llb;
-    mr = min(i__1,i__2);
+    mr = SUPERLU_MIN(i__1,i__2);
 /* Computing MIN */
     i__1 = *n, i__2 = *m + uub;
-    nc = min(i__1,i__2);
+    nc = SUPERLU_MIN(i__1,i__2);
 
     if (ipack == 5 || ipack == 6) {
 	minlda = uub + 1;
@@ -459,20 +460,20 @@ static logical c_false = FALSE_;
 /*     Use Givens rotation method if bandwidth small enough,   
        or if LDA is too small to store the matrix unpacked. */
 
-    givens = FALSE_;
+    givens = false;
     if (isym == 1) {
 /* Computing MAX */
 	i__1 = 1, i__2 = mr + nc;
-	if ((doublereal) (llb + uub) < (doublereal) max(i__1,i__2) * .3) {
-	    givens = TRUE_;
+	if ((double) (llb + uub) < (double) SUPERLU_MAX(i__1,i__2) * .3) {
+	    givens = true;
 	}
     } else {
 	if (llb << 1 < *m) {
-	    givens = TRUE_;
+	    givens = true;
 	}
     }
     if (*lda < *m && *lda >= minlda) {
-	givens = TRUE_;
+	givens = true;
     }
 
 /*     Set INFO if an error */
@@ -493,13 +494,14 @@ static logical c_false = FALSE_;
 	*info = -8;
     } else if (*kl < 0) {
 	*info = -10;
-    } else if (*ku < 0 || isym != 1 && *kl != *ku) {
+    } else if (*ku < 0 || (isym != 1 && *kl != *ku)) {
 	*info = -11;
-    } else if (ipack == -1 || isympk == 1 && isym == 1 || isympk == 2 && isym 
-	    == 1 && *kl > 0 || isympk == 3 && isym == 1 && *ku > 0 || isympk 
-	    != 0 && *m != *n) {
+    } else if ( ipack == -1 || (isympk == 1 && isym == 1) ||
+		(isympk == 2 && isym == 1 && *kl > 0) ||
+		(isympk == 3 && isym == 1 && *ku > 0) ||
+		(isympk != 0 && *m != *n) ) {
 	*info = -12;
-    } else if (*lda < max(1,minlda)) {
+    } else if (*lda < SUPERLU_MAX(1,minlda)) {
 	*info = -14;
     }
 
@@ -533,22 +535,22 @@ static logical c_false = FALSE_;
 /*     Choose Top-Down if D is (apparently) increasing,   
        Bottom-Up if D is (apparently) decreasing. */
 
-    if (abs(d[1]) <= (d__1 = d[mnmin], abs(d__1))) {
-	topdwn = TRUE_;
+    if (fabs(d[1]) <= (d__1 = d[mnmin], fabs(d__1))) {
+	topdwn = true;
     } else {
-	topdwn = FALSE_;
+	topdwn = false;
     }
 
     if (*mode != 0 && abs(*mode) != 6) {
 
 /*        Scale by DMAX */
 
-	temp = abs(d[1]);
+	temp = fabs(d[1]);
 	i__1 = mnmin;
 	for (i = 2; i <= i__1; ++i) {
 /* Computing MAX */
-	    d__2 = temp, d__3 = (d__1 = d[i], abs(d__1));
-	    temp = max(d__2,d__3);
+	    d__2 = temp, d__3 = (d__1 = d[i], fabs(d__1));
+	    temp = SUPERLU_MAX(d__2,d__3);
 /* L20: */
 	}
 
@@ -649,7 +651,7 @@ JKU, N )
 
    Computing MIN */
 		    i__3 = *m + jku;
-		    i__2 = min(i__3,*n) + jkl - 1;
+		    i__2 = SUPERLU_MIN(i__3,*n) + jkl - 1;
 		    for (jr = 1; jr <= i__2; ++jr) {
 			extra.r = 0., extra.i = 0.;
 			angle = dlarnd_slu(&c__1, &iseed[1]) * 
@@ -664,11 +666,11 @@ JKU, N )
 			s.r = z__1.r, s.i = z__1.i;
 /* Computing MAX */
 			i__3 = 1, i__4 = jr - jkl;
-			icol = max(i__3,i__4);
+			icol = SUPERLU_MAX(i__3,i__4);
 			if (jr < *m) {
 /* Computing MIN */
 			    i__3 = *n, i__4 = jr + jku;
-			    il = min(i__3,i__4) + 1 - icol;
+			    il = SUPERLU_MIN(i__3,i__4) + 1 - icol;
 			    L__1 = jr > jkl;
 			    zlarot_slu(&c_true, &L__1, &c_false, &il, &c, &s, &a[
 				    jr - iskew * icol + ioffst + icol * 
@@ -701,7 +703,7 @@ JKU, N )
 			    }
 /* Computing MAX */
 			    i__4 = 1, i__5 = jch - jku;
-			    irow = max(i__4,i__5);
+			    irow = SUPERLU_MAX(i__4,i__5);
 			    il = ir + 2 - irow;
 			    ctemp.r = 0., ctemp.i = 0.;
 			    iltemp = jch > jku;
@@ -727,7 +729,7 @@ JKU, N )
 
 /* Computing MAX */
 				i__4 = 1, i__5 = jch - jku - jkl;
-				icol = max(i__4,i__5);
+				icol = SUPERLU_MAX(i__4,i__5);
 				il = ic + 2 - icol;
 				extra.r = 0., extra.i = 0.;
 				L__1 = jch > jku + jkl;
@@ -754,7 +756,7 @@ JKL, JKU
 
    Computing MIN */
 		    i__3 = *n + jkl;
-		    i__2 = min(i__3,*m) + jku - 1;
+		    i__2 = SUPERLU_MIN(i__3,*m) + jku - 1;
 		    for (jc = 1; jc <= i__2; ++jc) {
 			extra.r = 0., extra.i = 0.;
 			angle = dlarnd_slu(&c__1, &iseed[1]) * 
@@ -769,11 +771,11 @@ JKL, JKU
 			s.r = z__1.r, s.i = z__1.i;
 /* Computing MAX */
 			i__3 = 1, i__4 = jc - jku;
-			irow = max(i__3,i__4);
+			irow = SUPERLU_MAX(i__3,i__4);
 			if (jc < *n) {
 /* Computing MIN */
 			    i__3 = *m, i__4 = jc + jkl;
-			    il = min(i__3,i__4) + 1 - irow;
+			    il = SUPERLU_MIN(i__3,i__4) + 1 - irow;
 			    L__1 = jc > jku;
 			    zlarot_slu(&c_false, &L__1, &c_false, &il, &c, &s, &
 				    a[irow - iskew * jc + ioffst + jc * 
@@ -806,7 +808,7 @@ JKL, JKU
 			    }
 /* Computing MAX */
 			    i__4 = 1, i__5 = jch - jkl;
-			    icol = max(i__4,i__5);
+			    icol = SUPERLU_MAX(i__4,i__5);
 			    il = ic + 2 - icol;
 			    ctemp.r = 0., ctemp.i = 0.;
 			    iltemp = jch > jkl;
@@ -831,7 +833,7 @@ JKL, JKU
 				s.r = z__1.r, s.i = z__1.i;
 /* Computing MAX */
 				i__4 = 1, i__5 = jch - jkl - jku;
-				irow = max(i__4,i__5);
+				irow = SUPERLU_MAX(i__4,i__5);
 				il = ir + 2 - irow;
 				extra.r = 0., extra.i = 0.;
 				L__1 = jch > jkl + jku;
@@ -866,11 +868,11 @@ JKL, JKU
 
    Computing MIN */
 		    i__2 = *m, i__3 = *n + jkl;
-		    iendch = min(i__2,i__3) - 1;
+		    iendch = SUPERLU_MIN(i__2,i__3) - 1;
 /* Computing MIN */
 		    i__2 = *m + jku;
 		    i__3 = 1 - jkl;
-		    for (jc = min(i__2,*n) - 1; jc >= i__3; --jc) {
+		    for (jc = SUPERLU_MIN(i__2,*n) - 1; jc >= i__3; --jc) {
 			extra.r = 0., extra.i = 0.;
 			angle = dlarnd_slu(&c__1, &iseed[1]) * 
 				6.2831853071795864769252867663;
@@ -884,11 +886,11 @@ JKL, JKU
 			s.r = z__1.r, s.i = z__1.i;
 /* Computing MAX */
 			i__2 = 1, i__4 = jc - jku + 1;
-			irow = max(i__2,i__4);
+			irow = SUPERLU_MAX(i__2,i__4);
 			if (jc > 0) {
 /* Computing MIN */
 			    i__2 = *m, i__4 = jc + jkl + 1;
-			    il = min(i__2,i__4) + 1 - irow;
+			    il = SUPERLU_MIN(i__2,i__4) + 1 - irow;
 			    L__1 = jc + jkl < *m;
 			    zlarot_slu(&c_false, &c_false, &L__1, &il, &c, &s, &
 				    a[irow - iskew * jc + ioffst + jc * 
@@ -916,10 +918,10 @@ JKL, JKU
 					dummy.r;
 				s.r = z__1.r, s.i = z__1.i;
 			    }
-			    ic = max(1,ic);
+			    ic = SUPERLU_MAX(1,ic);
 /* Computing MIN */
 			    i__5 = *n - 1, i__6 = jch + jku;
-			    icol = min(i__5,i__6);
+			    icol = SUPERLU_MIN(i__5,i__6);
 			    iltemp = jch + jku < *n;
 			    ctemp.r = 0., ctemp.i = 0.;
 			    i__5 = icol + 2 - ic;
@@ -941,7 +943,7 @@ JKL, JKU
 				s.r = z__1.r, s.i = z__1.i;
 /* Computing MIN */
 				i__5 = iendch, i__6 = jch + jkl + jku;
-				il = min(i__5,i__6) + 2 - jch;
+				il = SUPERLU_MIN(i__5,i__6) + 2 - jch;
 				extra.r = 0., extra.i = 0.;
 				L__1 = jch + jkl + jku <= iendch;
 				zlarot_slu(&c_false, &c_true, &L__1, &il, &c, &s,
@@ -970,11 +972,11 @@ L, M )
 
    Computing MIN */
 		    i__3 = *n, i__4 = *m + jku;
-		    iendch = min(i__3,i__4) - 1;
+		    iendch = SUPERLU_MIN(i__3,i__4) - 1;
 /* Computing MIN */
 		    i__3 = *n + jkl;
 		    i__4 = 1 - jku;
-		    for (jr = min(i__3,*m) - 1; jr >= i__4; --jr) {
+		    for (jr = SUPERLU_MIN(i__3,*m) - 1; jr >= i__4; --jr) {
 			extra.r = 0., extra.i = 0.;
 			angle = dlarnd_slu(&c__1, &iseed[1]) * 
 				6.2831853071795864769252867663;
@@ -988,11 +990,11 @@ L, M )
 			s.r = z__1.r, s.i = z__1.i;
 /* Computing MAX */
 			i__3 = 1, i__2 = jr - jkl + 1;
-			icol = max(i__3,i__2);
+			icol = SUPERLU_MAX(i__3,i__2);
 			if (jr > 0) {
 /* Computing MIN */
 			    i__3 = *n, i__2 = jr + jku + 1;
-			    il = min(i__3,i__2) + 1 - icol;
+			    il = SUPERLU_MIN(i__3,i__2) + 1 - icol;
 			    L__1 = jr + jku < *n;
 			    zlarot_slu(&c_true, &c_false, &L__1, &il, &c, &s, &a[
 				    jr - iskew * icol + ioffst + icol * 
@@ -1020,10 +1022,10 @@ L, M )
 					dummy.r;
 				s.r = z__1.r, s.i = z__1.i;
 			    }
-			    ir = max(1,ir);
+			    ir = SUPERLU_MAX(1,ir);
 /* Computing MIN */
 			    i__5 = *m - 1, i__6 = jch + jkl;
-			    irow = min(i__5,i__6);
+			    irow = SUPERLU_MIN(i__5,i__6);
 			    iltemp = jch + jkl < *m;
 			    ctemp.r = 0., ctemp.i = 0.;
 			    i__5 = irow + 2 - ir;
@@ -1044,7 +1046,7 @@ L, M )
 				s.r = z__1.r, s.i = z__1.i;
 /* Computing MIN */
 				i__5 = iendch, i__6 = jch + jkl + jku;
-				il = min(i__5,i__6) + 2 - jch;
+				il = SUPERLU_MIN(i__5,i__6) + 2 - jch;
 				extra.r = 0., extra.i = 0.;
 				L__1 = jch + jkl + jku <= iendch;
 				zlarot_slu(&c_true, &c_true, &L__1, &il, &c, &s, 
@@ -1095,10 +1097,10 @@ L, M )
 		    for (jc = 1; jc <= i__4; ++jc) {
 /* Computing MAX */
 			i__2 = 1, i__3 = jc - k;
-			irow = max(i__2,i__3);
+			irow = SUPERLU_MAX(i__2,i__3);
 /* Computing MIN */
 			i__2 = jc + 1, i__3 = k + 2;
-			il = min(i__2,i__3);
+			il = SUPERLU_MIN(i__2,i__3);
 			extra.r = 0., extra.i = 0.;
 			i__2 = jc - iskew * (jc + 1) + ioffg + (jc + 1) * 
 				a_dim1;
@@ -1130,7 +1132,7 @@ L, M )
 				ilda, &extra, &ctemp);
 /* Computing MIN */
 			i__3 = k, i__5 = *n - jc;
-			i__2 = min(i__3,i__5) + 1;
+			i__2 = SUPERLU_MIN(i__3,i__5) + 1;
 			zlarot_slu(&c_true, &c_true, &c_false, &i__2, &ct, &st, &
 				a[(1 - iskew) * jc + ioffg + jc * a_dim1], &
 				ilda, &ctemp, &dummy);
@@ -1177,10 +1179,10 @@ L, M )
 				    a_dim1], &ilda, &ctemp, &extra);
 /* Computing MAX */
 			    i__3 = 1, i__5 = jch - k;
-			    irow = max(i__3,i__5);
+			    irow = SUPERLU_MAX(i__3,i__5);
 /* Computing MIN */
 			    i__3 = jch + 1, i__5 = k + 2;
-			    il = min(i__3,i__5);
+			    il = SUPERLU_MIN(i__3,i__5);
 			    extra.r = 0., extra.i = 0.;
 			    L__1 = jch > k;
 			    zlarot_slu(&c_false, &L__1, &c_true, &il, &ct, &st, &
@@ -1206,7 +1208,7 @@ te that
 			if (zsym) {
 /* Computing MIN */
 			    i__2 = *n, i__3 = jc + uub;
-			    i__4 = min(i__2,i__3);
+			    i__4 = SUPERLU_MIN(i__2,i__3);
 			    for (jr = jc; jr <= i__4; ++jr) {
 				i__2 = jr + irow + jc * a_dim1;
 				i__3 = jc - iskew * jr + ioffg + jr * a_dim1;
@@ -1216,7 +1218,7 @@ te that
 			} else {
 /* Computing MIN */
 			    i__2 = *n, i__3 = jc + uub;
-			    i__4 = min(i__2,i__3);
+			    i__4 = SUPERLU_MIN(i__2,i__3);
 			    for (jr = jc; jr <= i__4; ++jr) {
 				i__2 = jr + irow + jc * a_dim1;
 				d_cnjg(&z__1, &a[jc - iskew * jr + ioffg + jr 
@@ -1272,7 +1274,7 @@ te that
 		    for (jc = *n - 1; jc >= 1; --jc) {
 /* Computing MIN */
 			i__4 = *n + 1 - jc, i__2 = k + 2;
-			il = min(i__4,i__2);
+			il = SUPERLU_MIN(i__4,i__2);
 			extra.r = 0., extra.i = 0.;
 			i__4 = (1 - iskew) * jc + 1 + ioffg + jc * a_dim1;
 			ctemp.r = a[i__4].r, ctemp.i = a[i__4].i;
@@ -1303,7 +1305,7 @@ te that
 				ctemp, &extra);
 /* Computing MAX */
 			i__4 = 1, i__2 = jc - k + 1;
-			icol = max(i__4,i__2);
+			icol = SUPERLU_MAX(i__4,i__2);
 			i__4 = jc + 2 - icol;
 			zlarot_slu(&c_true, &c_false, &c_true, &i__4, &ct, &st, &
 				a[jc - iskew * icol + ioffg + icol * a_dim1], 
@@ -1347,7 +1349,7 @@ te that
 				    a_dim1], &ilda, &extra, &ctemp);
 /* Computing MIN */
 			    i__3 = *n + 1 - jch, i__5 = k + 2;
-			    il = min(i__3,i__5);
+			    il = SUPERLU_MIN(i__3,i__5);
 			    extra.r = 0., extra.i = 0.;
 			    L__1 = *n - jch > k;
 			    zlarot_slu(&c_false, &c_true, &L__1, &il, &ct, &st, &
@@ -1372,7 +1374,7 @@ te that
 			if (zsym) {
 /* Computing MAX */
 			    i__2 = 1, i__4 = jc - uub;
-			    i__1 = max(i__2,i__4);
+			    i__1 = SUPERLU_MAX(i__2,i__4);
 			    for (jr = jc; jr >= i__1; --jr) {
 				i__2 = jr + irow + jc * a_dim1;
 				i__4 = jc - iskew * jr + ioffg + jr * a_dim1;
@@ -1382,7 +1384,7 @@ te that
 			} else {
 /* Computing MAX */
 			    i__2 = 1, i__4 = jc - uub;
-			    i__1 = max(i__2,i__4);
+			    i__1 = SUPERLU_MAX(i__2,i__4);
 			    for (jr = jc; jr >= i__1; --jr) {
 				i__2 = jr + irow + jc * a_dim1;
 				d_cnjg(&z__1, &a[jc - iskew * jr + ioffg + jr 
@@ -1564,7 +1566,7 @@ te that
 	    for (j = 1; j <= i__1; ++j) {
 /* Computing MIN */
 		i__2 = j + llb;
-		for (i = min(i__2,*m); i >= 1; --i) {
+		for (i = SUPERLU_MIN(i__2,*m); i >= 1; --i) {
 		    i__2 = i - j + uub + 1 + j * a_dim1;
 		    i__4 = i + j * a_dim1;
 		    a[i__2].r = a[i__4].r, a[i__2].i = a[i__4].i;
@@ -1577,7 +1579,7 @@ te that
 	    for (j = uub + 2; j <= i__1; ++j) {
 /* Computing MIN */
 		i__4 = j + llb;
-		i__2 = min(i__4,*m);
+		i__2 = SUPERLU_MIN(i__4,*m);
 		for (i = j - uub; i <= i__2; ++i) {
 		    i__4 = i - j + uub + 1 + j * a_dim1;
 		    i__3 = i + j * a_dim1;
@@ -1628,9 +1630,9 @@ te that
 /* Computing MAX   
    Computing MIN */
 		i__3 = ir1, i__5 = ir2 - jc;
-		i__2 = 1, i__4 = min(i__3,i__5);
+		i__2 = 1, i__4 = SUPERLU_MIN(i__3,i__5);
 		i__6 = *lda;
-		for (jr = max(i__2,i__4); jr <= i__6; ++jr) {
+		for (jr = SUPERLU_MAX(i__2,i__4); jr <= i__6; ++jr) {
 		    i__2 = jr + jc * a_dim1;
 		    a[i__2].r = 0., a[i__2].i = 0.;
 /* L510: */
