@@ -1,4 +1,4 @@
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -16,13 +16,20 @@ at the top-level directory.
  * October 15, 2003
  *
  */
-/*
- * File name:		ddrive.c
- * Purpose:             MAIN test program
+
+/*! \file
+ * DDRIVE is the main test program for the DOUBLE linear
+ * equation driver routines DGSSV and DGSSVX.
+ *
+ * The program is invoked by a shell script file -- dtest.csh.
+ * The output from the tests are written into a file -- dtest.out.
+ *
+ * \ingroup TestingD
  */
+#include <getopt.h>
 #include <string.h>
-#include <unistd.h>
 #include "slu_ddefs.h"
+#include "MATGEN/matgen.h"
 
 #define NTESTS    5      /* Number of test types */
 #define NTYPES    11     /* Number of matrix types */
@@ -37,20 +44,11 @@ parse_command_line(int argc, char *argv[], char *matrix_type,
 		   int *n, int *w, int *relax, int *nrhs, int *maxsuper,
 		   int *rowblk, int *colblk, int_t *lwork, double *u, FILE **fp);
 
+/*!
+ * Entry point of test program.
+ */
 int main(int argc, char *argv[])
 {
-/* 
- * Purpose
- * =======
- *
- * DDRIVE is the main test program for the DOUBLE linear 
- * equation driver routines DGSSV and DGSSVX.
- * 
- * The program is invoked by a shell script file -- dtest.csh.
- * The output from the tests are written into a file -- dtest.out.
- *
- * =====================================================================
- */
     double         *a, *a_save;
     int_t          *asub, *asub_save;
     int_t          *xa, *xa_save;
@@ -111,11 +109,6 @@ int main(int argc, char *argv[])
     extern int dgst07(trans_t, int, int, SuperMatrix *, double *, int,
                          double *, int, double *, int, 
                          double *, double *, double *);
-    extern int dlatb4_slu(char *, int *, int *, int *, char *, int *, int *, 
-	               double *, int *, double *, char *);
-    extern int dlatms_slu(int *, int *, char *, int *, char *, double *d,
-                       int *, double *, double *, int *, int *,
-                       char *, double *, int *, double *, int *);
     extern int sp_dconvert(int, int, double *, int, int, int,
 	                   double *a, int_t *, int_t *, int_t *);
 
@@ -522,7 +515,7 @@ int main(int argc, char *argv[])
     return 0;
 }
 
-/*  
+/*!
  * Parse command line options to get relaxed snode size, panel size, etc.
  */
 static void
