@@ -1,4 +1,4 @@
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -16,13 +16,21 @@ at the top-level directory.
  * October 15, 2003
  *
  */
-/*
- * File name:		sdrive.c
- * Purpose:             MAIN test program
+
+/*! \file
+ * SDRIVE is the main test program for the FLOAT linear
+ * equation driver routines SGSSV and SGSSVX.
+ *
+ * The program is invoked by a shell script file -- stest.csh.
+ * The output from the tests are written into a file -- stest.out.
+ *
+ * \ingroup TestingS
  */
+
+#include <getopt.h>
 #include <string.h>
-#include <unistd.h>
 #include "slu_sdefs.h"
+#include "MATGEN/matgen.h"
 
 #define NTESTS    5      /* Number of test types */
 #define NTYPES    11     /* Number of matrix types */
@@ -37,20 +45,11 @@ parse_command_line(int argc, char *argv[], char *matrix_type,
 		   int *n, int *w, int *relax, int *nrhs, int *maxsuper,
 		   int *rowblk, int *colblk, int_t *lwork, double *u, FILE **fp);
 
+/*!
+ * Entry point of test program.
+ */
 int main(int argc, char *argv[])
 {
-/* 
- * Purpose
- * =======
- *
- * SDRIVE is the main test program for the FLOAT linear 
- * equation driver routines SGSSV and SGSSVX.
- * 
- * The program is invoked by a shell script file -- stest.csh.
- * The output from the tests are written into a file -- stest.out.
- *
- * =====================================================================
- */
     float         *a, *a_save;
     int_t          *asub, *asub_save;
     int_t          *xa, *xa_save;
@@ -111,11 +110,6 @@ int main(int argc, char *argv[])
     extern int sgst07(trans_t, int, int, SuperMatrix *, float *, int,
                          float *, int, float *, int, 
                          float *, float *, float *);
-    extern int slatb4_slu(char *, int *, int *, int *, char *, int *, int *, 
-	               float *, int *, float *, char *);
-    extern int slatms_slu(int *, int *, char *, int *, char *, float *d,
-                       int *, float *, float *, int *, int *,
-                       char *, float *, int *, float *, int *);
     extern int sp_sconvert(int, int, float *, int, int, int,
 	                   float *a, int_t *, int_t *, int_t *);
 
@@ -522,7 +516,7 @@ int main(int argc, char *argv[])
     return 0;
 }
 
-/*  
+/*!
  * Parse command line options to get relaxed snode size, panel size, etc.
  */
 static void
